# Trimming-Tool
Trim images with transparent borders.
## How to use?
Run in the terminal with the file name(s) as arguments. E.g. python3 Trimmer.py "file1.png" "file2.png".
## Dependencies
```bash
pip install -r requirements.txt
```

or
```bash
pip install numpy
pip install opencv-python
```
